Converting skins to views:
==========================

[/] main:
---------
- [ ] main_template.pt (macros)
- [/] breadcrumbs.py -> UrsineGlobals.breadcrumbs
- [ ] expanded_title.py
- [ ] get_permalink.py
- [ ] permalink.py
- [/] getMainGlobals.py -> UrsineGlobals
- [ ] truncID.py

[ ] static resources:
---------------------
- [ ] discussionitem_icon.gif

- [ ] document_icon.gif

- [ ] file_icon.gif

- [ ] folder_icon.gif

- [ ] image_icon.gif

- [ ] link_icon.gif

- [ ] newsitem_icon.gif

- [ ] zpt_stylesheet.css

- [ ] * from Images layer
